@@ -9,10 +9,12 @@ from extreme_parser.util.parse import parse_number
 
 def parse_context(selector: parsel.Selector = None) -> Union[dict, None]:
     c = selector.re_first(r'Etsy.Context=({.*})', replace_entities=False)
+    c = c or selector.re_first(r'Etsy.Context.data : {}, ({.*})', replace_entities=False)
     if c is None:
         return None
-    else:
-        return json.loads(c)
+
+    c = json.loads(c)
+    return c["data"] if "data" in c else c
 
 
 def parse(html: str, p: Product):
@@ -42,7 +44,7 @@ def parse_shop_id(p: Product, selector: parsel.Selector = None):
         return
 
     try:
-        shop_id = context.get("data").get("shop_id")
+        shop_id = context.get("shop_id")
     except AttributeError:
         p.shop_id = None
     else:
@@ -56,7 +58,7 @@ def parse_price(p: Product, selector: parsel.Selector = None):
             return None
 
         try:
-            price = context.get("data").get("granify").get("product").get("price")
+            price = context.get("granify").get("product").get("price")
         except AttributeError:
             return None
         else:
@@ -107,7 +109,7 @@ def parse_stock(p: Product, selector: parsel.Selector = None):
         return
 
     try:
-        stock = context.get("data").get("granify").get("product").get("in_stock")
+        stock = context.get("granify").get("product").get("in_stock")
     except AttributeError:
         p.stock = None
     else:
@@ -134,7 +136,7 @@ def parse_currency(p: Product, selector: parsel.Selector = None):
         return
 
     try:
-        currency = context.get("data").get("locale_settings").get("currency").get("code")
+        currency = context.get("locale_settings").get("currency").get("code")
     except AttributeError:
         p.currency = None
     else:
